@@ -178,9 +178,72 @@ loocv.between <- function(x, nax = 0, progress = FALSE, parallel = FALSE, ...)
     names(xcoo1) <- names(PRESS1) <- names(PRESSTot) <- names(x$ls)
     res1 <- list(xcoo1, PRESS1, PRESSTot, oijb1m, oijb2m, (oijb2m-oijb1m)*200)
     names(res1) <- c("XValCoord", "PRESS", "PRESSTot", "Oij_bca", "Oij_XVal", "DeltaOij")
+    class(res1) <- "bcaloocv"
+    res1$call <- match.call()
     return(res1)
 }
 
+"print.bcaloocv" <- function (x, ...) 
+{
+    if (!inherits(x, "bcaloocv")) 
+        stop("to be used with 'bcaloocv' object")
+    cat("bca loocv object\n")
+    cat("call: ")
+    print(x$call)
+    cat("class: ")
+    cat(class(x), "\n")
+    cat("\n$Oij_bca:", x$Oij_bca)
+    cat("\n$Oij_XVal:", x$Oij_XVal)
+    cat("\n$DeltaOij:", x$DeltaOij, "%")
+	cat("\n\n")
+    sumry <- array("", c(4, 4), list(1:4, c("vector", "length", 
+        "mode", "content")))
+    sumry[1, ] <- c("$PRESSTot", length(x$PRESSTot), mode(x$PRESSTot), "Sum of PRESS for each bca axis")
+    sumry[2, ] <- c("$Oij_bca", length(x$Oij_bca), mode(x$Oij_bca), "mean overlap index for BGA")
+    sumry[3, ] <- c("$Oij_XVal", length(x$Oij_XVal), mode(x$Oij_XVal), "mean overlap index for cross-validation")
+    sumry[4, ] <- c("$DeltaOij", length(x$DeltaOij), mode(x$DeltaOij), "spuriousness index")
+    
+    print(sumry, quote = FALSE)
+    cat("\n")
+    sumry <- array("", c(2, 4), list(1:2, c("data.frame", "nrow", 
+        "ncol", "content")))
+    sumry[1, ] <- c("$XValCoord", nrow(x$XValCoord), ncol(x$XValCoord), "Cross-validates row coordinates")
+    sumry[2, ] <- c("$PRESS", nrow(x$PRESS), ncol(x$PRESS), "Predicted Residual Error Sum of Squares for each row")
+   
+    print(sumry, quote = FALSE)
+    cat("\n")
+}
+
+"plot.bcaloocv" <- function (x, xax = 1, yax = 2, ...) {
+    if (!inherits(x, "bcaloocv")) 
+        stop("Use only with 'bcaloocv' objects")
+    bca1 <- eval(x$call[[2]])
+    fac1 <- eval(bca1$call[[3]])
+    if (bca1$nf == 1) {
+        warnings("One axis only : not yet implemented")
+        return(invisible())
+    }
+	# Permutation test
+	rt1 <- randtest(bca1)
+	# Compute cross-validated coordinates
+	Oijbga <- x$Oij_bca
+	Oijxval <- x$Oij_XVal
+	dOij <- x$DeltaOij
+	par(mfrow=c(2,2))	
+	# Character string: graph title, permutation test p-value and variance ratio
+	pst1 <- paste0("Permutation test p = ", rt1$pvalue, ", Expl.Var = ", round(bca1$ratio, 2), ", Oij = ", round(Oijbga,2))
+	# Draw BGA factor map
+	s.class(bca1$ls[,c(xax, yax)], fac1, cstar = 1, cellipse = 0)
+	s.chull(bca1$ls[,c(xax, yax)], fac1, sub = pst1, optchull = 1, add.plot = TRUE)
+	# Compute cross-validated coordinates
+	# Character string for graph title
+	pst2 <- paste0("Cross-validation Oij = ", round(Oijxval,2), ", dOij = ", round(dOij), "%")
+	# Cross-validated factor map
+	s.class(x$XValCoord[,c(xax, yax)], fac1, cstar = 1, cellipse = 0)
+	s.chull(x$XValCoord[,c(xax, yax)], fac1, sub = pst2, optchull = 1, add.plot = TRUE)
+	# Display both factor maps side by side
+}
+
 loocv.discrimin <- function(x, nax = 0, progress = FALSE, ...)
     ## Leave-one-out cross-validation for discriminant analysis (aka CVA)
     ## x = the discrimin analysis to be cross-validated
@@ -299,9 +362,71 @@ loocv.discrimin <- function(x, nax = 0, progress = FALSE, ...)
 	names(xcoo1) <- names(PRESS1) <- names(PRESSTot) <- names(x$li[1:nf1])
     res1 <- list(xcoo1, PRESS1, PRESSTot, oijb1m, oijb2m, (oijb2m-oijb1m)*200)
     names(res1) <- c("XValCoord", "PRESS", "PRESSTot", "Oij_disc", "Oij_XVal", "DeltaOij")
+    class(res1) <- "discloocv"
+    res1$call <- match.call()
     return(res1)
 }
 
+"print.discloocv" <- function (x, ...) 
+{
+    if (!inherits(x, "discloocv")) 
+        stop("to be used with 'discloocv' object")
+    cat("Discrimin loocv object\n")
+    cat("call: ")
+    print(x$call)
+    cat("class: ")
+    cat(class(x), "\n")
+    cat("\n$Oij_disc:", x$Oij_disc)
+    cat("\n$Oij_XVal:", x$Oij_XVal)
+    cat("\n$DeltaOij:", x$DeltaOij, "%")
+	cat("\n\n")
+    sumry <- array("", c(4, 4), list(1:4, c("vector", "length", 
+        "mode", "content")))
+    sumry[1, ] <- c("$PRESSTot", length(x$PRESSTot), mode(x$PRESSTot), "Sum of PRESS for each bca axis")
+    sumry[2, ] <- c("$Oij_disc", length(x$Oij_disc), mode(x$Oij_disc), "mean overlap index for BGA")
+    sumry[3, ] <- c("$Oij_XVal", length(x$Oij_XVal), mode(x$Oij_XVal), "mean overlap index for cross-validation")
+    sumry[4, ] <- c("$DeltaOij", length(x$DeltaOij), mode(x$DeltaOij), "spuriousness index")
+    
+    print(sumry, quote = FALSE)
+    cat("\n")
+    sumry <- array("", c(2, 4), list(1:2, c("data.frame", "nrow", 
+        "ncol", "content")))
+    sumry[1, ] <- c("$XValCoord", nrow(x$XValCoord), ncol(x$XValCoord), "Cross-validates row coordinates")
+    sumry[2, ] <- c("$PRESS", nrow(x$PRESS), ncol(x$PRESS), "Predicted Residual Error Sum of Squares for each row")
+   
+    print(sumry, quote = FALSE)
+    cat("\n")
+}
+
+"plot.discloocv" <- function (x, xax = 1, yax = 2, ...) {
+    if (!inherits(x, "discloocv")) 
+        stop("Use only with 'discloocv' objects")
+    disc1 <- eval(x$call[[2]])
+    fac1 <- eval(disc1$call[[3]])
+    if (disc1$nf == 1) {
+        warnings("One axis only : not yet implemented")
+        return(invisible())
+    }
+	# Permutation test
+	rt1 <- randtest(disc1)
+	# Compute cross-validated coordinates
+	Oijdisc <- x$Oij_disc
+	Oijxval <- x$Oij_XVal
+	dOij <- x$DeltaOij
+	par(mfrow=c(2,2))	
+	# Character string: graph title, permutation test p-value and variance ratio
+	pst1 <- paste0("Permutation test p = ", rt1$pvalue, ", Oij = ", round(Oijdisc,2))
+	# Draw Discrimin factor map
+	s.class(disc1$li[,c(xax, yax)], fac1, cstar = 1, cellipse = 0)
+	s.chull(disc1$li[,c(xax, yax)], fac1, sub = pst1, optchull = 1, add.plot = TRUE)
+	# Compute cross-validated coordinates
+	# Character string for graph title
+	pst2 <- paste0("Cross-validation Oij = ", round(Oijxval,2), ", dOij = ", round(dOij), "%")
+	# Cross-validated factor map
+	s.class(x$XValCoord[,c(xax, yax)], fac1, cstar = 1, cellipse = 0)
+	s.chull(x$XValCoord[,c(xax, yax)], fac1, sub = pst2, optchull = 1, add.plot = TRUE)
+	# Display both factor maps side by side
+}
 
 loocv.dudi <- function(x, progress = FALSE, ...) 
     ## Leave-one-out cross-validation for a dudi analysis
